USE msdb
GO

/**********************************************************************************************
**	Update the trigger tr_EmailIntegrityJobOutput.
**********************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[tr_EmailIntegrityJobOutput]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[tr_EmailIntegrityJobOutput]
GO

SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS OFF
GO

/************************************************************************************************
**	Desc:	Adding a trigger(tr_EmailIntegrityJobOutput)to the sysjobhistory that will 
**		send a mail when a Database weekly Integrity 
**		check succeeds. (CR 2569)
**
**	Author: Kwame Adu-Poku
**
**	Date: 03/10/09
**************************************************************************************************
**	Modified:
**	Date		Name		Description
**************************************************************************************************/

CREATE  TRIGGER [dbo].[tr_EmailIntegrityJobOutput]

ON [dbo].[sysjobhistory]

FOR INSERT

AS 

DECLARE @emailbody 	VARCHAR(4000)
DECLARE @attachment VARCHAR(4000)
DECLARE @runstatus 	INT

IF EXISTS (SELECT * FROM inserted JOIN dbo.sysjobs ON inserted.job_id = dbo.sysjobs.job_id where inserted.step_name like '%WeeklyIntegrityCheck')

BEGIN

	SELECT @runstatus = run_status, @emailbody = 
	
		CONVERT(CHAR(15),'E-mail:') + '*** Please do not reply to this message. If you have any questions, please contact the VA Service Desk 1-888-596 HELP(4357)***' + CHAR(10) +
	
		CONVERT(CHAR(15),'Server:') + ISNULL(@@servername, '') + CHAR(10) +

		CONVERT(CHAR(15),'Job:') + ISNULL(CONVERT(VARCHAR(50), dbo.sysjobs.name), '') + CHAR(10) +

		CONVERT(CHAR(15),'Step:') + ISNULL(CONVERT(VARCHAR(50), inserted.step_name), '') + CHAR(10) +

		CONVERT(CHAR(15),'Action:') + CASE run_status WHEN 0 THEN 'FAILED' WHEN 1 THEN 'SUCCEED' WHEN 3 THEN 'CANCELED' ELSE '' END + CHAR(10) +

		CONVERT(CHAR(15),'Message:') + ISNULL(CONVERT(VARCHAR(150), inserted.message), '') + CHAR(10) +
	
		CONVERT(CHAR(15),'Attachment:') + ISNULL(CONVERT(VARCHAR(150), dbo.sysjobsteps.output_file_name),''),

		@attachment = dbo.sysjobsteps.output_file_name 
		
	FROM inserted 

	JOIN dbo.sysjobs
		ON inserted.job_id = dbo.sysjobs.job_id

	JOIN dbo.sysjobsteps
		ON inserted.job_id = [dbo].sysjobsteps.job_id
		AND inserted.step_id = [dbo].sysjobsteps.step_id
	
	WHERE inserted.run_status = '1'

	DECLARE @emailto varchar(1000)
	DECLARE @emailfrom varchar(1000)
	DECLARE @subject varchar(100)
	
	SET @subject = 'Job Succeeded'
	SET @emailfrom = '"No Replies" <vhaishops6a@va.gov>'


	CREATE TABLE  #TempXML 
	(LineText	VARCHAR(255),
	 Junk	INT)

	INSERT INTO #TempXML (LineText, Junk)
	EXEC sp_readerrorlog 1,  'C:\program files\vista\vbecs service monitor\VbecsServiceMonitor.exe.config'


	SELECT @emailto = LineText 
 	 FROM #TempXML
 	WHERE LineText LIKE '%<add key="EmailRecipients"%'

	DROP TABLE #TempXML

	DECLARE @position integer

	SET @position = charindex('value="', @emailto) + len('value="')
	SET @emailto = substring(@emailto, @position, charindex('"', @emailto, @position + 1) - @position)

	EXEC master.dbo.spSendVBECSJobMail @emailfrom, @emailto, @subject, @emailbody, @attachment

END


GO

/**********************************************************************************************
**	Update the trigger tr_EmailBackgroundJobsFailures.
**********************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[tr_EmailBackgroundJobsFailures]') and OBJECTPROPERTY(id, N'IsTrigger') = 1)
drop trigger [dbo].[tr_EmailBackgroundJobsFailures]
GO

SET QUOTED_IDENTIFIER OFF
GO
SET ANSI_NULLS OFF
GO
/************************************************************************************************
**	Desc: 	Adding a trigger (tr_EmailBackgroundJobsFailures) to the sysjobhistory that
**		will send a mail when any of the VBECS Background jobs fails.(CR 2569)
**
**	Author: Kwame Adu-Poku
**
**	Date: 	03/10/09
**************************************************************************************************
**	Modified:
**	Date		Name		Description
**************************************************************************************************/
CREATE TRIGGER [dbo].[tr_EmailBackgroundJobsFailures]

ON [dbo].[sysjobhistory]

FOR INSERT

AS 

DECLARE @emailbody varchar(4000)
DECLARE @attachment varchar(4000)

IF EXISTS (SELECT * FROM inserted WHERE run_status IN (0,3) AND step_name <> '(job outcome)')
BEGIN

	SELECT @emailbody = 

		CONVERT(CHAR(15),'E-mail:') + '*** Please do not reply to this message. If you have any questions, please contact the VA Service Desk 1-888-596 HELP (4357)***' + CHAR(10) +

		CONVERT(char(15),'Server:') + ISNULL(@@servername, '') + char(10) +

		CONVERT(char(15),'Job:') + ISNULL(CONVERT(VARCHAR(50), dbo.sysjobs.name), '') + char(10) +

		CONVERT(char(15),'Step:') + ISNULL(CONVERT(VARCHAR(50), inserted.step_name), '')+ char(10) +

		CONVERT(char(15),'Action:') + CASE run_status WHEN 0 THEN 'FAILED' WHEN 3 THEN 'CANCELED' ELSE '' END + char(10) +

		CONVERT(char(15),'Message:') + ISNULL(CONVERT(VARCHAR(150), inserted.message), '')+ char(10) +

		CONVERT(char(15),'Attachment:') + ISNULL(CONVERT(VARCHAR(150), dbo.sysjobsteps.output_file_name),''),

		@attachment = dbo.sysjobsteps.output_file_name

	FROM inserted 

	JOIN dbo.sysjobs
		ON inserted.job_id = dbo.sysjobs.job_id
	JOIN dbo.sysjobsteps
		ON inserted.job_id = dbo.sysjobsteps.job_id
		AND inserted.step_id = dbo.sysjobsteps.step_id

	WHERE inserted.run_status IN (0,3)



	DECLARE @emailto varchar(1000)
	DECLARE @emailfrom varchar(1000)
	DECLARE @subject varchar(100)

	SET @subject = 'Job Failed'
	SET @emailfrom = '"No Replies" <vhaishops6a@va.gov>'

	CREATE TABLE  #Temp2XML 
	(LineText	VARCHAR(255),
	 Junk	INT)

	INSERT INTO #Temp2XML (LineText, Junk)

	EXEC sp_readerrorlog 1,  'C:\program files\vista\vbecs service monitor\VbecsServiceMonitor.exe.config'

	SELECT @emailto = LineText 
  	FROM #Temp2XML
 	WHERE LineText LIKE '%<add key="EmailRecipients"%'

	DROP TABLE #Temp2XML

	DECLARE @position integer

	SET @position = charindex('value="', @emailto) + len('value="')
	SET @emailto = substring(@emailto, @position, charindex('"', @emailto, @position + 1) - @position)

	EXEC master.dbo.spSendVBECSJobMail @emailfrom, @emailto, @subject, @emailbody, @attachment

END


GO

/**********************************************************************************************
**	Delete the daily integrity check jobs.
**********************************************************************************************/
BEGIN TRANSACTION

DECLARE @JobID BINARY(16)  

-- Delete the master_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'master_DailyIntegrityCheck')
       
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''master_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'master_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION

DECLARE @JobID BINARY(16) 

-- Delete the msdb_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'msdb_DailyIntegrityCheck') 
      
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''msdb_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'msdb_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO
-- Script generated on 8/31/2011 8:53 AM
-- By: VHAMASTER\VHAISHSmithM
-- Server: VHASTLSQLZ1

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'Master_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''Master_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'Master_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'Master_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run Master_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''Master'', NOINDEX)  ', @database_name = N'Master', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'D:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\master\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'Master_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070501, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'msdb_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''msdb_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'msdb_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'msdb_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run msdb_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''msdb'', NOINDEX)  ', @database_name = N'msdb', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'D:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\msdb\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'msdb_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070501, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 


GO

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'Copy VBECS DB Backups to L Drive')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''Copy VBECS DB Backups to L Drive'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'Copy VBECS DB Backups to L Drive' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'Copy VBECS DB Backups to L Drive', @owner_login_name = N'sa', @description = N'Copies VBECS DB backups from D Drive to the L Drive and renames the files to include date time.', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Copy Backups to L Drive', @command = N'USE master

declare @sql	varchar(2000)

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD\VBECS_V1_PROD.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD\VBECS_V1_PROD_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD_MIRROR\VBECS_V1_PROD_MIRROR.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_PROD_MIRROR\VBECS_V1_PROD_MIRROR_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST\VBECS_V1_TEST.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST\VBECS_V1_TEST_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql= ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST_MIRROR\VBECS_V1_TEST_MIRROR.BAK" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\VBECS_V1_TEST_MIRROR\VBECS_V1_TEST_MIRROR_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\master\master.bak" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\master\master_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql

set @sql = ''copy "D:\Program Files\Microsoft SQL Server\MSSQL\Backup\msdb\msdb.bak" "L:\Program Files\Microsoft SQL Server\MSSQL\Backup\msdb\msdb_'' + CAST(DATEPART(YEAR,GETDATE()) AS VARCHAR(4)) +
 RIGHT(''0'' + CAST(DATEPART(MONTH,GETDATE()) AS VARCHAR(2)),2) +  RIGHT(''0'' + CAST(DATEPART(DAY,GETDATE()) AS VARCHAR(2)),2) + ''.BAK"''

exec master..xp_cmdshell @sql', @database_name = N'master', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'Copy Backup Schedule', @enabled = 1, @freq_type = 4, @active_start_date = 20090205, @active_start_time = 24000, @freq_interval = 1, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 0, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'L Drive Delete old Backup files')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''L Drive Delete old Backup files'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'L Drive Delete old Backup files' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'L Drive Delete old Backup files', @owner_login_name = N'sa', @description = N'Delete old backup files that are more than 7 days old', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'delete old files', @command = N'Use Master

CREATE TABLE #BackupFiles 
(FullPathName NVARCHAR(256)) 


DECLARE @Command NVARCHAR(256) 


SET @Command = ''master.dbo.xp_cmdshell ''''DIR ''
   + ''"L:\Program Files\Microsoft SQL Server\MSSQL\Backup\'' + ''*.*" /B /S''''''

INSERT INTO #BackupFiles EXEC (@Command) 


DECLARE @DeleteFiles NVARCHAR(4000) 

DECLARE file_cursor CURSOR FAST_FORWARD FOR 

SELECT  '' exec xp_cmdshell ''''DEL "'' 
       + FullPathName + ''"'''''' +CHAR(13)+CHAR(10) 
FROM #BackupFiles 
WHERE (FullPathName LIKE ''%_%.BAK'') 
   -- Trims punctuation and space from date time string 
     
  AND RIGHT(FullPathName,10) <
      CONVERT(VARCHAR(10),
      DATEADD(DAY, -6, GETDATE()),12)


OPEN file_cursor 
FETCH NEXT FROM file_cursor INTO @DeleteFiles 


WHILE @@FETCH_STATUS = 0 
BEGIN 
   EXEC (@DeleteFiles) 
   FETCH NEXT FROM file_cursor INTO @DeleteFiles 
END 


CLOSE file_cursor 
DEALLOCATE file_cursor 

DROP TABLE #BackupFiles', @database_name = N'master', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'L Drive Delete old Backup files', @enabled = 1, @freq_type = 4, @active_start_date = 20081201, @active_start_time = 25000, @freq_interval = 1, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 0, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO


/**********************************************************************************************
**	Delete the daily integrity check jobs.
**********************************************************************************************/
BEGIN TRANSACTION

DECLARE @JobID BINARY(16) 

-- Delete the VBECS_V1_PROD_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_PROD_DailyIntegrityCheck') 
      
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''VBECS_V1_PROD_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_PROD_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION

DECLARE @JobID BINARY(16) 

-- Delete the VBECS_V1_PROD_MIRROR_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_PROD_MIRROR_DailyIntegrityCheck') 
      
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''VBECS_V1_PROD_MIRROR_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_PROD_MIRROR_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION
            
DECLARE @JobID BINARY(16)  

-- Delete the VBECS_V1_PROD_ExpireTestOrders job (if it exists)  
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_PROD_ExpireTestOrders')

IF (@JobID IS NOT NULL)    
BEGIN  
  -- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
	-- There is, so abort the script 
	RAISERROR (N'Unable to import job ''VBECS_V1_PROD_ExpireTestOrders'' since there is already a multi-server job with this name.', 16, 1) 
	GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_PROD_ExpireTestOrders' 
	SET @JobID = NULL
END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

/**********************************************************************************************
**	Add the new weekly integrity check jobs.
**********************************************************************************************/
BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'VBECS_V1_PROD_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''VBECS_V1_PROD_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_PROD_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'VBECS_V1_PROD_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 3, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run VBECS_V1_PROD_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''VBECS_V1_PROD'', NOINDEX)  ', @database_name = N'VBECS_V1_PROD', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'd:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'VBECS_V1_PROD_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070328, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''VBECS_V1_PROD_MIRROR'', NOINDEX)  ', @database_name = N'VBECS_V1_PROD_MIRROR', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'd:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_PROD_MIRROR\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'VBECS_V1_PROD_MIRROR_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070328, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 
