USE msdb
GO

/**********************************************************************************************
**	Delete the daily integrity check jobs.
**********************************************************************************************/
BEGIN TRANSACTION

DECLARE @JobID BINARY(16) 

-- Delete the VBECS_V1_TEST_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_TEST_DailyIntegrityCheck') 
      
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''VBECS_V1_TEST_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_TEST_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

BEGIN TRANSACTION

DECLARE @JobID BINARY(16) 

-- Delete the VBECS_V1_TEST_MIRROR_DailyIntegrityCheck job (if it exists)
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_TEST_MIRROR_DailyIntegrityCheck') 
      
IF (@JobID IS NOT NULL)    
BEGIN  
	-- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
		-- There is, so abort the script 
		RAISERROR (N'Unable to import job ''VBECS_V1_TEST_MIRROR_DailyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
		GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_TEST_MIRROR_DailyIntegrityCheck' 
	SET @JobID = NULL
END 
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO


BEGIN TRANSACTION
            
DECLARE @JobID BINARY(16)  

-- Delete the VBECS_V1_TEST_ExpireTestOrders job (if it exists)  
SELECT @JobID = job_id     
FROM   msdb.dbo.sysjobs    
WHERE (name = N'VBECS_V1_TEST_ExpireTestOrders')

IF (@JobID IS NOT NULL)    
BEGIN  
  -- Check if the job is a multi-server job  
	IF (EXISTS (SELECT  * 
	      FROM    msdb.dbo.sysjobservers 
	      WHERE   (job_id = @JobID) AND (server_id <> 0))) 
	BEGIN 
	-- There is, so abort the script 
	RAISERROR (N'Unable to import job ''VBECS_V1_TEST_ExpireTestOrders'' since there is already a multi-server job with this name.', 16, 1) 
	GOTO QuitWithRollback  
	END 
	ELSE 
		-- Delete the [local] job 
		EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_TEST_ExpireTestOrders' 
	SET @JobID = NULL
END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO

/**********************************************************************************************
**	Add the new weekly integrity check jobs.
**********************************************************************************************/
BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'VBECS_V1_TEST_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''VBECS_V1_TEST_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_TEST_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'VBECS_V1_TEST_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 3, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run VBECS_V1_TEST_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''VBECS_V1_TEST'', NOINDEX)  ', @database_name = N'VBECS_V1_TEST', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'd:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'VBECS_V1_TEST_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070328, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 

GO
BEGIN TRANSACTION            
  DECLARE @JobID BINARY(16)  
  DECLARE @ReturnCode INT    
  SELECT @ReturnCode = 0     
IF (SELECT COUNT(*) FROM msdb.dbo.syscategories WHERE name = N'[Uncategorized (Local)]') < 1 
  EXECUTE msdb.dbo.sp_add_category @name = N'[Uncategorized (Local)]'

  -- Delete the job with the same name (if it exists)
  SELECT @JobID = job_id     
  FROM   msdb.dbo.sysjobs    
  WHERE (name = N'VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck')       
  IF (@JobID IS NOT NULL)    
  BEGIN  
  -- Check if the job is a multi-server job  
  IF (EXISTS (SELECT  * 
              FROM    msdb.dbo.sysjobservers 
              WHERE   (job_id = @JobID) AND (server_id <> 0))) 
  BEGIN 
    -- There is, so abort the script 
    RAISERROR (N'Unable to import job ''VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck'' since there is already a multi-server job with this name.', 16, 1) 
    GOTO QuitWithRollback  
  END 
  ELSE 
    -- Delete the [local] job 
    EXECUTE msdb.dbo.sp_delete_job @job_name = N'VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck' 
    SELECT @JobID = NULL
  END 

BEGIN 

  -- Add the job
  EXECUTE @ReturnCode = msdb.dbo.sp_add_job @job_id = @JobID OUTPUT , @job_name = N'VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck', @owner_login_name = N'sa', @description = N'Checks integrity of database - resource intensive operation!', @category_name = N'[Uncategorized (Local)]', @enabled = 1, @notify_level_email = 0, @notify_level_page = 0, @notify_level_netsend = 0, @notify_level_eventlog = 2, @delete_level= 0
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job steps
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobstep @job_id = @JobID, @step_id = 1, @step_name = N'Run VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck', @command = N'DBCC CHECKDB(''VBECS_V1_TEST_MIRROR'', NOINDEX)  ', @database_name = N'VBECS_V1_TEST_MIRROR', @server = N'', @database_user_name = N'', @subsystem = N'TSQL', @cmdexec_success_code = 0, @flags = 0, @retry_attempts = 0, @retry_interval = 1, @output_file_name = N'd:\Program Files\Microsoft SQL Server\MSSQL\BACKUP\VBECS_V1_TEST_MIRROR\DatabaseIntegrityReport.log', @on_success_step_id = 0, @on_success_action = 1, @on_fail_step_id = 0, @on_fail_action = 2
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 
  EXECUTE @ReturnCode = msdb.dbo.sp_update_job @job_id = @JobID, @start_step_id = 1 

  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the job schedules
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobschedule @job_id = @JobID, @name = N'VBECS_V1_TEST_MIRROR_WeeklyIntegrityCheck Schedule', @enabled = 1, @freq_type = 8, @active_start_date = 20070328, @active_start_time = 1150, @freq_interval = 64, @freq_subday_type = 1, @freq_subday_interval = 0, @freq_relative_interval = 0, @freq_recurrence_factor = 1, @active_end_date = 99991231, @active_end_time = 235959
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

  -- Add the Target Servers
  EXECUTE @ReturnCode = msdb.dbo.sp_add_jobserver @job_id = @JobID, @server_name = N'(local)' 
  IF (@@ERROR <> 0 OR @ReturnCode <> 0) GOTO QuitWithRollback 

END
COMMIT TRANSACTION          
GOTO   EndSave              
QuitWithRollback:
  IF (@@TRANCOUNT > 0) ROLLBACK TRANSACTION 
EndSave: 
